import axios from 'axios'
import { Toast } from 'vant'
import { API_BASE_URL } from './config'

// 创建axios实例
const service = axios.create({
  baseURL: API_BASE_URL, // 从配置文件获取基础URL
  timeout: 10000 // 请求超时时间
})

// 请求拦截器
service.interceptors.request.use(
  config => {
    // 在发送请求之前可以做一些处理
    return config
  },
  error => {
    // 处理请求错误
    console.log(error)
    return Promise.reject(error)
  }
)

// 响应拦截器
service.interceptors.response.use(
  response => {
    const res = response.data
    // 根据后端约定的状态码判断请求是否成功
    if (res.code !== 200) {
      Toast.fail(res.message || '请求失败')
      return Promise.reject(new Error(res.message || '请求失败'))
    } else {
      return res
    }
  },
  error => {
    console.log('请求错误:', error)
    Toast.fail('网络异常，请稍后重试')
    return Promise.reject(error)
  }
)

export default service 